# -*- coding: utf-8 -*-
import scrapy
from scrapy.linkextractors import LinkExtractor
from scrapy.spiders import CrawlSpider, Rule
from hacg.items import ArticleItem, CommentItem
from datetime import datetime


class LiuliSpider(CrawlSpider):
    name = 'liuli'
    allowed_domains = ['liuli.se']
    start_urls = ['https://www.liuli.se/wp']

    rules = (
        Rule(LinkExtractor(allow=r'https://www\.liuli\.se/wp/page/\d*'), callback=None, follow=True),
        Rule(LinkExtractor(allow=r'https://www.liuli.se/wp/\d+\.html'), callback="parse_page", follow=False),
    )

    def parse_page(self, response):
        #文章id
        post_id = response.xpath('//article/@id').get().split('-')[1]
        guid = 'http://192.168.64.2/?p=' + post_id
        article = response.xpath('//div[@id="content"]')
        #文章标题
        title = article.xpath('//h1[@class="entry-title"]/text()').get()
        #发布时间
        s = article.xpath('.//time/@datetime').getall()[0]
        pub_time = ' '.join(s.split('+')[0].split('T'))
        #作者
        author = article.xpath('.//span[@class="author vcard"]/a/text()').get()
        #正文
        content = ''.join(article.xpath('.//div[@class="entry-content"]/*').getall())
        item = ArticleItem(guid=guid, title=title, author=author, pub_time=pub_time, content=content)
        item['ID'] = post_id
        if item['title']:
            yield item

        #评论列表
        comments = response.xpath('.//div[@class="wc-comment-right"]')
        for comment in comments:
            #评论id
            comment_id =  comment.xpath('./@id').get().split('-')[1]
            #对应文章id
            comment_post_id = post_id
            #评论者
            comment_author = comment.xpath('.//div[@class="wc-comment-author "]/text()').get()
            #评论内容
            comment_content = ''.join(comment.xpath('.//div[@class="wc-comment-text"]//text()').getall()).strip()
            #评论时间
            s = comment.xpath('.//div[@class="wc-comment-date"]//text()').get().replace('年','-').replace('月','-').replace(' 上午','AM ').replace('下午','PM ').replace('日',' ')
            dt = datetime.strptime(s, '%Y-%m-%d %p %I:%M')
            comment_date = datetime.strftime(dt, '%Y-%m-%d %H:%M:%S')
            item = CommentItem(comment_id=comment_id, comment_post_id=comment_post_id, comment_author=comment_author,
                                comment_content=comment_content, comment_date=comment_date, comment_date_gmt=comment_date)
            item['comment_author_email'] = '123321@gmail.com'
            if item['comment_author']:
                yield item